My toughest trip by Robert William Reading | Project Gutenberg
Description: Free kindle book and epub digitized and proofread by volunteers.
Keywords: ebook, ebooks, free ebooks, free books, book, books, audio books

# My toughest trip by Robert William Reading

## Read now or download (free!)

| Choose how to read this book | Url | Size |  |  |
--- | --- | --- | --- | --- | --- | ---
| Read online (web) | https://www.gutenberg.org/ebooks/74700.html.images | 35 kB |  |  |
| EPUB3 (E-readers incl. Send-to-Kindle) | https://www.gutenberg.org/ebooks/74700.epub3.images | 322 kB |  |  |
| EPUB (older E-readers) | https://www.gutenberg.org/ebooks/74700.epub.images | 321 kB |  |  |
| EPUB (no images, older E-readers) | https://www.gutenberg.org/ebooks/74700.epub.noimages | 159 kB |  |  |
| Kindle | https://www.gutenberg.org/ebooks/74700.kf8.images | 887 kB |  |  |
| older Kindles | https://www.gutenberg.org/ebooks/74700.kindle.images | 881 kB |  |  |
| Plain Text UTF-8 | https://www.gutenberg.org/ebooks/74700.txt.utf-8 | 28 kB |  |  |
| Download HTML (zip) | https://www.gutenberg.org/cache/epub/74700/pg74700-h.zip | 586 kB |  |  |
| There may be more files related to this item.

## Similar Books

Readers also downloaded…
In Browsing: History - General
In Browsing: Travel & Geography

## About this eBook

Author | Reading, Robert William
Title | My toughest trip
Original Publication | Chicago, IL: The Consolidated Magazines Corporation, 1927.
Note | Reading ease score: 78.5 (7th grade). Fairly easy to read.
Note | Produced from the May 1927 issue of Blue Book magazine.
Credits | Roger Frank and Sue Clark
Summary | "My Toughest Trip" by Sergeant Reading is an Arctic adventure narrative written in the early 20th century. As an account from a member of the Royal Northwest Mounted Police (now the Royal Canadian Mounted Police), the book provides a unique glimpse into the challenges faced by officers patrolling the harsh Arctic landscape and interacting with the local Inuit populations. The narrative centers around the intense experiences and responsibilities of a Mountie, particularly during a rescue mission that takes a dramatic turn. The storyline follows Sergeant Reading as he undertakes the task of returning an Eskimo woman, Nuttinook, to her rightful husband after resolving a dispute over her abduction. During their journey, they face unforeseen hardships when a storm leaves them stranded on an island. Compounding their troubles, Nuttinook unexpectedly gives birth to a baby girl, while Reading is left to navigate both the emotional and physical challenges of keeping the newborn alive in the unforgiving Arctic wilderness. Throughout the ordeal, Reading showcases his resourcefulness and determination, ultimately fulfilling his duty and returning the child to her community despite the heartbreaking loss of her mother. The account emphasizes both the difficulty and the nobility of the work done by the Mounties in the Arctic, contrasting romanticized portrayals with the realities of their experiences. (This is an automatically generated summary.)
Language | English
LoC Class | PS: Language and Literatures: American and Canadian literature
Subject | Short stories
Subject | Canada, Northern -- Fiction
Subject | Shipwrecks -- Fiction
Subject | Royal North West Mounted Police (Canada) -- Fiction
Subject | Infants -- Fiction
Subject | Inuit -- Canada -- Fiction
Category | Text
EBook-No. | 74700
Release Date | Nov 7, 2024
Most Recently Updated | Jan 27, 2025
Copyright Status | Public domain in the USA.
Downloads | 147 downloads in the last 30 days.
Project Gutenberg eBooks are always free!